<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>OutputJACKFactory</name>
    <message>
        <location filename="../outputjackfactory.cpp" line="33"/>
        <source>JACK Plugin</source>
        <translation>Modulo JACK</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="56"/>
        <source>About Jack Output Plugin</source>
        <translation>Informazioni sul modulo JACK in nuscita</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="57"/>
        <source>Qmmp Jack Output Plugin</source>
        <translation>Modulo JACK d&apos;uscita Qmmp</translation>
    </message>
    <message>
        <location filename="../outputjackfactory.cpp" line="58"/>
        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>Autore: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</translation>
    </message>
</context>
</TS>
